import questionary.question
import os
from rich import print
import typer
from cookiecutter.main import cookiecutter
import questionary
from typing import Annotated
from .generate import Generate
from .api import Github
from .translate import Translate
from .module import Module
from jst_aicommit.main import JstAiCommit

app = typer.Typer()

BASE_DIR = os.getcwd()


def error(data):
    print(f"[bold red]{data}[/bold red]")


def success(data):
    print(f"[bold green]{data}[/bold green]")


def info(data):
    print(f"[bold blue]{data}[/bold blue]")


@app.command(name="install", help="Modul o'rnatish")
def install_module(
    module_name: Annotated[str, typer.Argument()] = None,
    version: str = typer.Option(None, "--version", "-v")
):
    Module().run(module_name, version)


@app.command(name="create", help="Yangi loyiha yaratish")
def create_project(version: str = typer.Option(None, "--version", "-v")):
    if version is None:
        version = Github().latest_release()
        print("version: ", version)
    else:
        Github().releases(version)
    template = questionary.text("Template: ", default="django").ask()
    if template.startswith("http") is not True:
        template = "https://github.com/JscorpTech/{}".format(template)
    cookiecutter(template, checkout=version)


@app.command(name="generate", help="Compoment generatsiya qilish")
def generate():
    Generate().run()


@app.command(name="aic", help="O'zgarishlarga qarab atomatik git commit yaratadi")
def aic():
    JstAiCommit().run()


@app.command(name="translate", help="Avtomatik tarjima")
def translate():
    Translate().run()


if __name__ == "__main__":
    app()



import isort
from typing import Union
import black


class Code:
    def __init__(self) -> None:
        pass

    @staticmethod
    def format_code(self, file_path: Union[str]) -> None:
        """Black and Isort format code"""
        isort.settings.Config(profile="black", line_length=120)
        with open(file_path, "r") as file:
            code = isort.code(black.format_str(file.read(), mode=black.FileMode()))
        with open(file_path, "w") as file:
            file.write(code)



import zipfile
import tempfile
import requests
import os
from .api import Github
import questionary
import shutil
from uuid import uuid4
from typing import Union


class Module:
    modules = {
        "authbot": "https://github.com/JscorpTech/module-authbot.git",
        "websocket": "https://github.com/JscorpTech/module-websocket.git",
        "default": "https://github.com/JscorpTech/module-default.git",
    }

    def __init__(self): ...

    def _subfolder_to_parent(self, path):
        """ichki papkadagi ko'dlarni parent papkaga ko'chirish"""
        extracted_file = os.path.join(path, os.listdir(path)[0])

        for file in os.listdir(extracted_file):
            shutil.move(os.path.join(extracted_file, file), path)
        os.rmdir(extracted_file)

    def _download(self, url, dir) -> Union[str]:
        """modulni yuklash"""
        file = os.path.join(dir, "%s.zip" % uuid4())
        with requests.get(url, stream=True) as response:
            response.raise_for_status()
            with open(file, "wb") as zip_file:
                for chunk in response.iter_content(chunk_size=8192):
                    zip_file.write(chunk)
        return file

    def _extract(self, module_name, zip_path):
        modules_dir = os.path.join(os.getcwd(), "core/apps/")
        extract_dir = os.path.join(modules_dir, module_name)
        if os.path.exists(extract_dir):
            raise Exception("Modul mavjud")
        os.makedirs(extract_dir, exist_ok=True)

        with zipfile.ZipFile(zip_path, "r") as zip_ref:
            zip_ref.extractall(extract_dir)
        return extract_dir

    def _download_and_extract_module(self, module_name, url):
        with tempfile.TemporaryDirectory() as temp_dir:
            # Download the module
            zip_path = self._download(url, temp_dir)
            # Extract the module
            extract_dir = self._extract(module_name, zip_path)
            # Move the module to the correct location
            self._subfolder_to_parent(extract_dir)

            with open(os.path.join(extract_dir, "apps.py"), "r+") as file:
                data = file.read()
                file.seek(0)
                file.write(data.replace("{{module_name}}", module_name))
                file.truncate()

    def run(self, module_name, version=None):
        module = questionary.select("Modulni tanlang", choices=self.modules.keys()).ask()
        api = Github("module-%s" % module)
        if module_name is None:
            module_name = module
        if version is None:
            version = api.latest_release()
        else:
            api.releases(version)
        module = "https://github.com/JscorpTech/module-{}/archive/refs/tags/{}.zip".format(module, version)

        self._download_and_extract_module(module_name, module)
        print("Modul o'rnatish yakunlandi")



from typing import Union, List, Tuple, Any
import requests
from .logger import logging
from polib import pofile
from tqdm import tqdm
import questionary
import os


class Translate:
    messages = None

    def __init__(self) -> None:
        self.langs: Union[List] = [
            "uzn_Latn",
            "uzn_Cyrl",
            "rus_Cyrl",
            "eng_Latn",
        ]

    def translate(self, message, source, target) -> Union[Tuple]:
        url = "https://websocket.tahrirchi.uz/handle-batch"

        payload = {"jobs": [{"text": message}], "source_lang": source, "target_lang": target}
        headers = {
            "Accept": "application/json, text/plain, */*",
            "Accept-Language": "uz,en-US;q=0.9,en;q=0.8,ru;q=0.7",
            "Connection": "keep-alive",
            "Content-Type": "application/json",
            "Origin": "https://tahrirchi.uz",
            "Referer": "https://tahrirchi.uz/",
            "Sec-Fetch-Dest": "empty",
            "Sec-Fetch-Mode": "cors",
            "Sec-Fetch-Site": "same-site",
            "User-Agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/130.0.0.0 Safari/537.36",
            "sec-ch-ua": '"Chromium";v="130", "Google Chrome";v="130", "Not?A_Brand";v="99"',
            "sec-ch-ua-mobile": "?0",
            "sec-ch-ua-platform": '"Linux"',
            "content-type": "application/json",
        }
        try:
            response = requests.post(url, json=payload, headers=headers)
            return True, response.json()["sentences"][0]["translated"]
        except Exception as e:
            logging.error(e)
            return False, message

    def get_messages(self, path: Union[str]) -> Any:
        messages = pofile(path)
        self.messages = messages
        return messages

    def get_pofiles(self) -> Union[List]:
        res = []
        for i in os.listdir(os.path.join(os.getcwd(), "resources/locale")):
            if not i.startswith("."):
                res.append(i)
        return res

    def run(self) -> None:
        pofiles = self.get_pofiles()
        file = questionary.select("Fayil joylashgan papkani tanlang: resources/locale", choices=pofiles).ask()
        source = questionary.select("Hozirli fayil tilini tanlang: ", choices=self.langs).ask()
        target = questionary.select("Tarjima qilish kerak bo'lgan til: ", choices=self.langs).ask()
        self.get_messages(os.path.join(os.getcwd(), "resources/locale/{}/LC_MESSAGES/django.po".format(file)))
        progress = tqdm(total=len(self.messages))
        for index, message in enumerate(self.messages):
            if message.msgstr != "":
                continue
            message.msgstr = self.translate(message.msgid, source, target)[1]
            progress.update(1)
            if index % 10 == 0:
                self.messages.save()
        self.messages.save()
        logging.info("Tarjima qilish yakunlandi!!!")
